@@ -41,10 +41,22 @@ struct _GUPnPContextClass {
         void (* _gupnp_reserved4) (void);
 };
 
+G_DEPRECATED_FOR(gupnp_context_new_for_address)
 GUPnPContext *
-gupnp_context_new                      (const char   *iface,
-                                        guint         port,
-                                        GError      **error);
+gupnp_context_new (const char *iface, guint port, GError **error);
+
+GUPnPContext *
+gupnp_context_new_for_address (GInetAddress *addr,
+                               guint16 port,
+                               GSSDPUDAVersion uda_version,
+                               GError **error);
+
+GUPnPContext *
+gupnp_context_new_full (const char *iface,
+                        GInetAddress *addr,
+                        guint16 port,
+                        GSSDPUDAVersion uda_version,
+                        GError **error);
 
 guint
 gupnp_context_get_port                 (GUPnPContext *context);
